cgdat.qt_custom.qt_dialogs — CGDAT 2.0.8 documentation

# cgdat.qt_custom.qt_dialogs

This file contains some dialog classes that are created for the CGDAT GUI. These classes inherit from the QtWidgets.Qdialog Class.

Classes

`importDialog`([parent]) | This class overloads the qt python class that was generated by yQt5.uic.pyuic converter for the importDialog so it can be used as a dialog in our main GUI.
`outputSettingsDialog`([parent]) | This class overloads the qt python class that was generated by yQt5.uic.pyuic converter for the output_settings_ui so it can be used as a dialog in our main GUI.
`progressDialog`([parent]) | This class overloads the qt python class that was generated by yQt5.uic.pyuic converter for the progressDialog so it can be used as a dialog in our main GUI.